@@ -1,30 +1,41 @@
 package Dist::Zilla::Plugin::PPPort;
 {
-  $Dist::Zilla::Plugin::PPPort::VERSION = '0.004';
+  $Dist::Zilla::Plugin::PPPort::VERSION = '0.005';
 }
 
 use 5.008;
 use Moose;
 with qw/Dist::Zilla::Role::FileGatherer/;
+use MooseX::Types::Perl qw(VersionObject);
+use MooseX::Types::Path::Class qw(File);
 use Devel::PPPort;
 
 my $content;
 {
 	local *PPPORT_FILE;
 	open PPPORT_FILE, '>', \$content or confess "Couldn't open scalar filehandle";
-	Devel::PPPort::WriteFile("&=".__PACKAGE__."::PPPORT_FILE");
+	Devel::PPPort::WriteFile("&=Dist::Zilla::Plugin::PPPort::PPPORT_FILE");
 	close PPPORT_FILE;
 }
 
 has filename => (
 	is => 'ro',
-	isa => 'Str',
-	default => 'ppport.h'
+	isa => File,
+	default => 'ppport.h',
+	coerce => 1,
+);
+
+has version => (
+	is => 'ro',
+	isa => VersionObject,
+	default => 0,
+	coerce => 1,
 );
 
 sub gather_files {
 	my $self = shift;
-	$self->add_file(Dist::Zilla::File::InMemory->new(name => $self->filename, content => $content));
+	Devel::PPPort->VERSION($self->version) if $self->version;
+	$self->add_file(Dist::Zilla::File::InMemory->new(name => $self->filename->stringify, content => $content));
 	return;
 }
 
@@ -34,8 +45,6 @@ no Moose;
 
 1;
 
-
-
 =pod
 
 =head1 NAME
@@ -44,7 +53,7 @@ Dist::Zilla::Plugin::PPPort - PPPort for Dist::Zilla
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -73,7 +82,6 @@ the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
 __END__
 
 #ABSTRACT: PPPort for Dist::Zilla
